@@ -1,5 +1,5 @@
 package LWP::Debug::TraceHTTP;
-$LWP::Debug::TraceHTTP::VERSION = '6.25';
+$LWP::Debug::TraceHTTP::VERSION = '6.27';
 # Just call:
 #
 #   require LWP::Debug::TraceHTTP;
@@ -11,8 +11,9 @@ $LWP::Debug::TraceHTTP::VERSION = '6.25';
 use strict;
 use base 'LWP::Protocol::http';
 
-package LWP::Debug::TraceHTTP::Socket;
-$LWP::Debug::TraceHTTP::Socket::VERSION = '6.25';
+package # hide from PAUSE
+    LWP::Debug::TraceHTTP::Socket;
+
 use Data::Dump 1.13;
 use Data::Dump::Trace qw(autowrap mcall);
 
